protocolMap.C3WepProtocolMap

|  | ## Cheshire3 Object Model: Class C3WepProtocolMap

Module protocolMap :: Class C3WepProtocolMap

## Class C3WepProtocolMap
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
      baseObjects.ProtocolMap --+
                                |
                ZeerexProtocolMap --+
                                    |
                                   C3WepProtocolMap

Instance Methods

__init__(self, session, node, parent)
_walkZeeRex(self, session, node)
Inherited from `baseObjects.ProtocolMap`: `resolve_index` Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

Inherited from `ZeerexProtocolMap`: `c3Namespace`, `protocol`, `version` Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### __init__(self, session, node, parent) (Constructor) | source code
Overrides: ZeerexProtocolMap.__init__

### _walkZeeRex(self, session, node) | source code